@@ -11,7 +11,6 @@ import (
 	"sync/atomic"
 	"time"
 	"unicode"
-	"unicode/utf8"
 
 	"github.com/cyrus-and/gdb"
 	"github.com/xyproto/clip"
@@ -72,12 +71,13 @@ type Editor struct {
 	highlightCurrentLine       bool            // highlight the current line
 	highlightCurrentText       bool            // highlight the current text (not the entire line)
 	// atomic.Bool are used for values that might be read when redrawing text asynchronously
-	changed      atomic.Bool // has the contents changed, since last save?
-	redraw       atomic.Bool // if the contents should be redrawn in the next loop
-	redrawCursor atomic.Bool // if the cursor should be moved to the location it is supposed to be
-	drawProgress atomic.Bool // used for drawing the progress character on the right side
-	drawFuncName atomic.Bool // used when drawing the function name in the top right corner
-	nanoMode     atomic.Bool // emulate GNU Nano
+	changed           atomic.Bool // has the contents changed, since last save?
+	redraw            atomic.Bool // if the contents should be redrawn in the next loop
+	redrawCursor      atomic.Bool // if the cursor should be moved to the location it is supposed to be
+	drawProgress      atomic.Bool // used for drawing the progress character on the right side
+	drawFuncName      atomic.Bool // used when drawing the function name in the top right corner
+	nanoMode          atomic.Bool // emulate GNU Nano
+	waitWithRedrawing atomic.Bool // wait with redrawing until a key is pressed
 }
 
 // Copy makes a copy of an Editor struct, with most fields deep copied
@@ -127,7 +127,7 @@ func (e *Editor) Copy() *Editor {
 	e2.monitorAndReadOnly = e.monitorAndReadOnly
 	e2.primaryClipboard = e.primaryClipboard
 	e2.jumpToLetterMode = e.jumpToLetterMode
-	e2.nanoMode = e.nanoMode
+	e2.nanoMode.Store(e.nanoMode.Load())
 	e2.spellCheckMode = e.spellCheckMode
 	e2.createDirectoriesIfMissing = e.createDirectoriesIfMissing
 	e2.displayQuickHelp = e.displayQuickHelp
@@ -231,12 +231,6 @@ func (e *Editor) ScreenLine(n int) string {
 	return ""
 }
 
-// LastDataPosition returns the last X index for this line, for the data (does not expand tabs)
-// Can be negative, if the line is empty.
-func (e *Editor) LastDataPosition(n LineIndex) int {
-	return utf8.RuneCountInString(e.Line(n)) - 1
-}
-
 // LastScreenPosition returns the last X index for this line, for the screen (expands tabs)
 // Can be negative, if the line is empty.
 func (e *Editor) LastScreenPosition(n LineIndex) int {
@@ -2187,22 +2181,6 @@ func (e *Editor) NewLine(c *vt100.Canvas, status *StatusBar) {
 	e.Down(c, status)
 }
 
-// ChopLine takes a string where the tabs have been expanded
-// and scrolls it + chops it up for display in the current viewport.
-// e.pos.offsetX and the given viewportWidth are respected.
-func (e *Editor) ChopLine(line string, viewportWidth int) string {
-	var screenLine string
-	// Shorten the screen line to account for the X offset
-	if utf8.RuneCountInString(line) > e.pos.offsetX {
-		screenLine = line[e.pos.offsetX:]
-	}
-	// Shorten the screen line to account for the terminal width
-	if len(string(screenLine)) >= viewportWidth {
-		screenLine = screenLine[:viewportWidth]
-	}
-	return screenLine
-}
-
 // HorizontalScrollIfNeeded will scroll along the X axis, if needed
 func (e *Editor) HorizontalScrollIfNeeded(c *vt100.Canvas) {
 	x := e.pos.sx
