@@ -10,7 +10,6 @@ import (
 	"sync/atomic"
 	"time"
 	"unicode"
-	"unicode/utf8"
 
 	"github.com/xyproto/clip"
 	"github.com/xyproto/digraph"
@@ -112,7 +111,7 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 	if *parentIsMan {
 		// The parent process is "man", but NROFF_FILENAME has not been set:
 		// This means that ctrl-space has been pressed a second time when editing an Nroff file, so switch back to Nroff mode.
-		if env.No("NROFF_FILENAME") {
+		if env.Has("ORBITON_SPACE") && env.No("NROFF_FILENAME") {
 			e.mode = mode.Nroff
 		} else {
 			e.mode = mode.ManPage
@@ -2140,7 +2139,7 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 
 				wrapped := e.InsertRune(c, r)
 				e.WriteRune(c)
-				if !wrapped && utf8.RuneCountInString(string(r)) > 0 {
+				if !wrapped {
 					// Move to the next position
 					e.Next(c)
 				}
@@ -2206,7 +2205,9 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 					highlightTimerMut.Lock()
 					defer highlightTimerMut.Unlock()
 					justMovedUpOrDownOrLeftOrRight := kh.PrevIsWithin(arrowKeyHighlightTime, "↓", "↑")
-					if !justMovedUpOrDownOrLeftOrRight && regularEditingRightNow {
+					if e.waitWithRedrawing.Load() {
+						e.waitWithRedrawing.Store(false)
+					} else if !justMovedUpOrDownOrLeftOrRight && regularEditingRightNow {
 						e.redraw.Store(true)
 						e.redrawCursor.Store(true)
 						e.RedrawAtEndOfKeyLoop(c, status, false, true)
