@@ -202,7 +202,7 @@ func NewOrbTheme() Theme {
 		SearchHighlight:             vt100.LightMagenta,
 		MultiLineComment:            vt100.Gray,
 		MultiLineString:             vt100.LightCyan,
-		HighlightForeground:         vt100.LightBlue,
+		HighlightForeground:         vt100.White,
 		HighlightBackground:         vt100.BackgroundBlack,
 		Git:                         vt100.LightCyan,
 		String:                      "cyan",
@@ -463,7 +463,7 @@ func NewSynthwaveTheme() Theme {
 		SearchHighlight:             vt100.LightMagenta,
 		MultiLineComment:            vt100.Gray,
 		MultiLineString:             vt100.Magenta,
-		HighlightForeground:         vt100.LightMagenta,
+		HighlightForeground:         vt100.White,
 		HighlightBackground:         vt100.BackgroundDefault,
 		Git:                         vt100.Cyan,
 		String:                      "lightgray",
@@ -550,7 +550,7 @@ func NewTealTheme() Theme {
 		SearchHighlight:             vt100.Red,
 		MultiLineComment:            vt100.Gray,
 		MultiLineString:             vt100.Blue,
-		HighlightForeground:         vt100.Gray,
+		HighlightForeground:         vt100.White,
 		HighlightBackground:         vt100.BackgroundDefault,
 		Git:                         vt100.Blue,
 		String:                      "lightcyan",
@@ -812,14 +812,14 @@ func NewDarkBlueEditTheme() Theme {
 		StatusErrorForeground:       vt100.Red,
 		StatusErrorBackground:       vt100.BackgroundCyan,
 		SearchHighlight:             vt100.Red,
-		MultiLineComment:            vt100.LightGray,
+		MultiLineComment:            vt100.White,
 		MultiLineString:             vt100.White,
 		HighlightForeground:         vt100.LightYellow,
 		HighlightBackground:         vt100.BackgroundBlue,
 		Git:                         vt100.White,
 		String:                      "lightyellow",
 		Keyword:                     "lightyellow",
-		Comment:                     "lightgray",
+		Comment:                     "white",
 		Type:                        "white",
 		Literal:                     "white",
 		Punctuation:                 "white",
@@ -1362,6 +1362,7 @@ func (e *Editor) setLightVSTheme() {
 }
 
 // setBlueEditTheme sets a blue/yellow/gray theme, for light or dark backgrounds
+// if given "true" as an argument, then a light background is assumed
 func (e *Editor) setBlueEditTheme(bs ...bool) {
 	if len(bs) == 1 {
 		initialLightBackground = &(bs[0])
@@ -1373,11 +1374,6 @@ func (e *Editor) setBlueEditTheme(bs ...bool) {
 	}
 }
 
-// setLightBlueEditTheme sets a blue/yellow/gray theme, for light backgrounds
-func (e *Editor) setLightBlueEditTheme() {
-	e.SetTheme(NewLightBlueEditTheme())
-}
-
 // setGratTheme sets a gray theme
 func (e *Editor) setGrayTheme() {
 	e.SetTheme(NewGrayTheme())
